@@ -8,6 +8,8 @@
 
 # AWS RDS Aurora serverless cluster from snapshot
 
+> Deprecated: Use https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_rds.ServerlessClusterFromSnapshot.html
+
 This project provides a CDK construct creating a serverless database cluster from a snapshot with AWS RDS Aurora engine.
 
 See [API.md](https://github.com/pepperize/cdk-serverless-cluster-from-snapshot/blob/main/API.md)
@@ -65,8 +67,9 @@ class ServerlessClusterFromSnapshot(
     metaclass=jsii.JSIIMeta,
     jsii_type="@pepperize/cdk-serverless-cluster-from-snapshot.ServerlessClusterFromSnapshot",
 ):
-    '''A Serverless Cluster restored from a snapshot.
+    '''(deprecated) A Serverless Cluster restored from a snapshot.
 
+    :stability: deprecated
     :resource: AWS::RDS::DBInstance
     '''
 
@@ -95,22 +98,24 @@ class ServerlessClusterFromSnapshot(
         '''
         :param scope: -
         :param id: -
-        :param engine: What kind of database to start.
-        :param snapshot_identifier: The identifier for the DB snapshot or DB cluster snapshot to restore from. You can use either the name or the Amazon Resource Name (ARN) to specify a DB cluster snapshot. However, you can use only the ARN to specify a DB snapshot. After you restore a DB cluster with a SnapshotIdentifier property, you must specify the same SnapshotIdentifier property for any future updates to the DB cluster. When you specify this property for an update, the DB cluster is not restored from the snapshot again, and the data in the database is not changed. However, if you don't specify the SnapshotIdentifier property, an empty DB cluster is created, and the original DB cluster is deleted. If you specify a property that is different from the previous snapshot restore property, a new DB cluster is restored from the specified SnapshotIdentifier property, and the original DB cluster is deleted.
-        :param vpc: The VPC that this Aurora Serverless cluster has been created in.
-        :param backup_retention: The number of days during which automatic DB snapshots are retained. Automatic backup retention cannot be disabled on serverless clusters. Must be a value from 1 day to 35 days. Default: Duration.days(1)
-        :param cluster_identifier: An optional identifier for the cluster. Default: - A name is automatically generated.
-        :param credentials: Credentials for the administrative user. Default: - A username of 'admin' and SecretsManager-generated password
-        :param default_database_name: Name of a database which is automatically created inside the cluster. Default: - Database is not created in cluster.
-        :param deletion_protection: Indicates whether the DB cluster should have deletion protection enabled. Default: - true if removalPolicy is RETAIN, false otherwise
-        :param enable_data_api: Whether to enable the Data API. Default: false
-        :param parameter_group: Additional parameters to pass to the database engine. Default: - no parameter group.
-        :param removal_policy: The removal policy to apply when the cluster and its instances are removed from the stack or replaced during an update. Default: - RemovalPolicy.SNAPSHOT (remove the cluster and instances, but retain a snapshot of the data)
-        :param scaling: Scaling configuration of an Aurora Serverless database cluster. Default: - Serverless cluster is automatically paused after 5 minutes of being idle. minimum capacity: 2 ACU maximum capacity: 16 ACU
-        :param security_groups: Security group. Default: - a new security group is created.
-        :param storage_encryption_key: The KMS key for storage encryption. If you specify the SnapshotIdentifier property, the StorageEncrypted property value is inherited from the snapshot, and if the DB cluster is encrypted, the specified KmsKeyId property is used. Default: - the default master key will be used for storage encryption
-        :param subnet_group: Existing subnet group for the cluster. Default: - a new subnet group will be created.
-        :param vpc_subnets: Where to place the instances within the VPC. Default: - the VPC default strategy if not specified.
+        :param engine: (deprecated) What kind of database to start.
+        :param snapshot_identifier: (deprecated) The identifier for the DB snapshot or DB cluster snapshot to restore from. You can use either the name or the Amazon Resource Name (ARN) to specify a DB cluster snapshot. However, you can use only the ARN to specify a DB snapshot. After you restore a DB cluster with a SnapshotIdentifier property, you must specify the same SnapshotIdentifier property for any future updates to the DB cluster. When you specify this property for an update, the DB cluster is not restored from the snapshot again, and the data in the database is not changed. However, if you don't specify the SnapshotIdentifier property, an empty DB cluster is created, and the original DB cluster is deleted. If you specify a property that is different from the previous snapshot restore property, a new DB cluster is restored from the specified SnapshotIdentifier property, and the original DB cluster is deleted.
+        :param vpc: (deprecated) The VPC that this Aurora Serverless cluster has been created in.
+        :param backup_retention: (deprecated) The number of days during which automatic DB snapshots are retained. Automatic backup retention cannot be disabled on serverless clusters. Must be a value from 1 day to 35 days. Default: Duration.days(1)
+        :param cluster_identifier: (deprecated) An optional identifier for the cluster. Default: - A name is automatically generated.
+        :param credentials: (deprecated) Credentials for the administrative user. Default: - A username of 'admin' and SecretsManager-generated password
+        :param default_database_name: (deprecated) Name of a database which is automatically created inside the cluster. Default: - Database is not created in cluster.
+        :param deletion_protection: (deprecated) Indicates whether the DB cluster should have deletion protection enabled. Default: - true if removalPolicy is RETAIN, false otherwise
+        :param enable_data_api: (deprecated) Whether to enable the Data API. Default: false
+        :param parameter_group: (deprecated) Additional parameters to pass to the database engine. Default: - no parameter group.
+        :param removal_policy: (deprecated) The removal policy to apply when the cluster and its instances are removed from the stack or replaced during an update. Default: - RemovalPolicy.SNAPSHOT (remove the cluster and instances, but retain a snapshot of the data)
+        :param scaling: (deprecated) Scaling configuration of an Aurora Serverless database cluster. Default: - Serverless cluster is automatically paused after 5 minutes of being idle. minimum capacity: 2 ACU maximum capacity: 16 ACU
+        :param security_groups: (deprecated) Security group. Default: - a new security group is created.
+        :param storage_encryption_key: (deprecated) The KMS key for storage encryption. If you specify the SnapshotIdentifier property, the StorageEncrypted property value is inherited from the snapshot, and if the DB cluster is encrypted, the specified KmsKeyId property is used. Default: - the default master key will be used for storage encryption
+        :param subnet_group: (deprecated) Existing subnet group for the cluster. Default: - a new subnet group will be created.
+        :param vpc_subnets: (deprecated) Where to place the instances within the VPC. Default: - the VPC default strategy if not specified.
+
+        :stability: deprecated
         '''
         props = ServerlessClusterFromSnapshotProps(
             engine=engine,
@@ -144,7 +149,7 @@ class ServerlessClusterFromSnapshot(
         exclude_characters: typing.Optional[builtins.str] = None,
         vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
     ) -> aws_cdk.aws_secretsmanager.SecretRotation:
-        '''Adds the multi user rotation to this cluster.
+        '''(deprecated) Adds the multi user rotation to this cluster.
 
         :param id: -
         :param secret: The secret to rotate. It must be a JSON string with the following format:: { "engine": <required: database engine>, "host": <required: instance host name>, "username": <required: username>, "password": <required: password>, "dbname": <optional: database name>, "port": <optional: if not specified, default port will be used>, "masterarn": <required: the arn of the master secret which will be used to create users/change passwords> }
@@ -152,6 +157,8 @@ class ServerlessClusterFromSnapshot(
         :param endpoint: The VPC interface endpoint to use for the Secrets Manager API. If you enable private DNS hostnames for your VPC private endpoint (the default), you don't need to specify an endpoint. The standard Secrets Manager DNS hostname the Secrets Manager CLI and SDKs use by default (https://secretsmanager..amazonaws.com) automatically resolves to your VPC endpoint. Default: https://secretsmanager..amazonaws.com
         :param exclude_characters: Specifies characters to not include in generated passwords. Default: " %+~`#$&*()|[]{}:;<>?!'/
         :param vpc_subnets: Where to place the rotation Lambda function. Default: - same placement as instance or cluster
+
+        :stability: deprecated
         '''
         options = aws_cdk.aws_rds.RotationMultiUserOptions(
             secret=secret,
@@ -172,12 +179,14 @@ class ServerlessClusterFromSnapshot(
         exclude_characters: typing.Optional[builtins.str] = None,
         vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
     ) -> aws_cdk.aws_secretsmanager.SecretRotation:
-        '''Adds the single user rotation of the master password to this cluster.
+        '''(deprecated) Adds the single user rotation of the master password to this cluster.
 
         :param automatically_after: Specifies the number of days after the previous rotation before Secrets Manager triggers the next automatic rotation. Default: - 30 days
         :param endpoint: The VPC interface endpoint to use for the Secrets Manager API. If you enable private DNS hostnames for your VPC private endpoint (the default), you don't need to specify an endpoint. The standard Secrets Manager DNS hostname the Secrets Manager CLI and SDKs use by default (https://secretsmanager..amazonaws.com) automatically resolves to your VPC endpoint. Default: https://secretsmanager..amazonaws.com
         :param exclude_characters: Specifies characters to not include in generated passwords. Default: " %+~`#$&*()|[]{}:;<>?!'/
         :param vpc_subnets: Where to place the rotation Lambda function. Default: - same placement as instance or cluster
+
+        :stability: deprecated
         '''
         options = aws_cdk.aws_rds.RotationSingleUserOptions(
             automatically_after=automatically_after,
@@ -192,7 +201,10 @@ class ServerlessClusterFromSnapshot(
     def as_secret_attachment_target(
         self,
     ) -> aws_cdk.aws_secretsmanager.SecretAttachmentTargetProps:
-        '''Renders the secret attachment target specifications.'''
+        '''(deprecated) Renders the secret attachment target specifications.
+
+        :stability: deprecated
+        '''
         return typing.cast(aws_cdk.aws_secretsmanager.SecretAttachmentTargetProps, jsii.invoke(self, "asSecretAttachmentTarget", []))
 
     @jsii.member(jsii_name="grantDataApiAccess")
@@ -200,51 +212,74 @@ class ServerlessClusterFromSnapshot(
         self,
         grantee: aws_cdk.aws_iam.IGrantable,
     ) -> aws_cdk.aws_iam.Grant:
-        '''Grant the given identity to access to the Data API, including read access to the secret attached to the cluster if present.
+        '''(deprecated) Grant the given identity to access to the Data API, including read access to the secret attached to the cluster if present.
 
         :param grantee: The principal to grant access to.
+
+        :stability: deprecated
         '''
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantDataApiAccess", [grantee]))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="clusterArn")
     def cluster_arn(self) -> builtins.str:
-        '''The ARN of the cluster.'''
+        '''(deprecated) The ARN of the cluster.
+
+        :stability: deprecated
+        '''
         return typing.cast(builtins.str, jsii.get(self, "clusterArn"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="clusterEndpoint")
     def cluster_endpoint(self) -> aws_cdk.aws_rds.Endpoint:
-        '''The endpoint to use for read/write operations.'''
+        '''(deprecated) The endpoint to use for read/write operations.
+
+        :stability: deprecated
+        '''
         return typing.cast(aws_cdk.aws_rds.Endpoint, jsii.get(self, "clusterEndpoint"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="clusterIdentifier")
     def cluster_identifier(self) -> builtins.str:
-        '''Identifier of the cluster.'''
+        '''(deprecated) Identifier of the cluster.
+
+        :stability: deprecated
+        '''
         return typing.cast(builtins.str, jsii.get(self, "clusterIdentifier"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="clusterReadEndpoint")
     def cluster_read_endpoint(self) -> aws_cdk.aws_rds.Endpoint:
-        '''The endpoint to use for read/write operations.'''
+        '''(deprecated) The endpoint to use for read/write operations.
+
+        :stability: deprecated
+        '''
         return typing.cast(aws_cdk.aws_rds.Endpoint, jsii.get(self, "clusterReadEndpoint"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="connections")
     def connections(self) -> aws_cdk.aws_ec2.Connections:
-        '''Access to the network connections.'''
+        '''(deprecated) Access to the network connections.
+
+        :stability: deprecated
+        '''
         return typing.cast(aws_cdk.aws_ec2.Connections, jsii.get(self, "connections"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="secret")
     def secret(self) -> typing.Optional[aws_cdk.aws_secretsmanager.ISecret]:
-        '''The secret attached to this cluster.'''
+        '''(deprecated) The secret attached to this cluster.
+
+        :stability: deprecated
+        '''
         return typing.cast(typing.Optional[aws_cdk.aws_secretsmanager.ISecret], jsii.get(self, "secret"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="enableDataApi")
     def _enable_data_api(self) -> typing.Optional[builtins.bool]:
+        '''
+        :stability: deprecated
+        '''
         return typing.cast(typing.Optional[builtins.bool], jsii.get(self, "enableDataApi"))
 
     @_enable_data_api.setter
@@ -295,24 +330,26 @@ class ServerlessClusterFromSnapshotProps:
         subnet_group: typing.Optional[aws_cdk.aws_rds.ISubnetGroup] = None,
         vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
     ) -> None:
-        '''Properties to configure an Aurora Serverless Cluster.
+        '''(deprecated) Properties to configure an Aurora Serverless Cluster.
 
-        :param engine: What kind of database to start.
-        :param snapshot_identifier: The identifier for the DB snapshot or DB cluster snapshot to restore from. You can use either the name or the Amazon Resource Name (ARN) to specify a DB cluster snapshot. However, you can use only the ARN to specify a DB snapshot. After you restore a DB cluster with a SnapshotIdentifier property, you must specify the same SnapshotIdentifier property for any future updates to the DB cluster. When you specify this property for an update, the DB cluster is not restored from the snapshot again, and the data in the database is not changed. However, if you don't specify the SnapshotIdentifier property, an empty DB cluster is created, and the original DB cluster is deleted. If you specify a property that is different from the previous snapshot restore property, a new DB cluster is restored from the specified SnapshotIdentifier property, and the original DB cluster is deleted.
-        :param vpc: The VPC that this Aurora Serverless cluster has been created in.
-        :param backup_retention: The number of days during which automatic DB snapshots are retained. Automatic backup retention cannot be disabled on serverless clusters. Must be a value from 1 day to 35 days. Default: Duration.days(1)
-        :param cluster_identifier: An optional identifier for the cluster. Default: - A name is automatically generated.
-        :param credentials: Credentials for the administrative user. Default: - A username of 'admin' and SecretsManager-generated password
-        :param default_database_name: Name of a database which is automatically created inside the cluster. Default: - Database is not created in cluster.
-        :param deletion_protection: Indicates whether the DB cluster should have deletion protection enabled. Default: - true if removalPolicy is RETAIN, false otherwise
-        :param enable_data_api: Whether to enable the Data API. Default: false
-        :param parameter_group: Additional parameters to pass to the database engine. Default: - no parameter group.
-        :param removal_policy: The removal policy to apply when the cluster and its instances are removed from the stack or replaced during an update. Default: - RemovalPolicy.SNAPSHOT (remove the cluster and instances, but retain a snapshot of the data)
-        :param scaling: Scaling configuration of an Aurora Serverless database cluster. Default: - Serverless cluster is automatically paused after 5 minutes of being idle. minimum capacity: 2 ACU maximum capacity: 16 ACU
-        :param security_groups: Security group. Default: - a new security group is created.
-        :param storage_encryption_key: The KMS key for storage encryption. If you specify the SnapshotIdentifier property, the StorageEncrypted property value is inherited from the snapshot, and if the DB cluster is encrypted, the specified KmsKeyId property is used. Default: - the default master key will be used for storage encryption
-        :param subnet_group: Existing subnet group for the cluster. Default: - a new subnet group will be created.
-        :param vpc_subnets: Where to place the instances within the VPC. Default: - the VPC default strategy if not specified.
+        :param engine: (deprecated) What kind of database to start.
+        :param snapshot_identifier: (deprecated) The identifier for the DB snapshot or DB cluster snapshot to restore from. You can use either the name or the Amazon Resource Name (ARN) to specify a DB cluster snapshot. However, you can use only the ARN to specify a DB snapshot. After you restore a DB cluster with a SnapshotIdentifier property, you must specify the same SnapshotIdentifier property for any future updates to the DB cluster. When you specify this property for an update, the DB cluster is not restored from the snapshot again, and the data in the database is not changed. However, if you don't specify the SnapshotIdentifier property, an empty DB cluster is created, and the original DB cluster is deleted. If you specify a property that is different from the previous snapshot restore property, a new DB cluster is restored from the specified SnapshotIdentifier property, and the original DB cluster is deleted.
+        :param vpc: (deprecated) The VPC that this Aurora Serverless cluster has been created in.
+        :param backup_retention: (deprecated) The number of days during which automatic DB snapshots are retained. Automatic backup retention cannot be disabled on serverless clusters. Must be a value from 1 day to 35 days. Default: Duration.days(1)
+        :param cluster_identifier: (deprecated) An optional identifier for the cluster. Default: - A name is automatically generated.
+        :param credentials: (deprecated) Credentials for the administrative user. Default: - A username of 'admin' and SecretsManager-generated password
+        :param default_database_name: (deprecated) Name of a database which is automatically created inside the cluster. Default: - Database is not created in cluster.
+        :param deletion_protection: (deprecated) Indicates whether the DB cluster should have deletion protection enabled. Default: - true if removalPolicy is RETAIN, false otherwise
+        :param enable_data_api: (deprecated) Whether to enable the Data API. Default: false
+        :param parameter_group: (deprecated) Additional parameters to pass to the database engine. Default: - no parameter group.
+        :param removal_policy: (deprecated) The removal policy to apply when the cluster and its instances are removed from the stack or replaced during an update. Default: - RemovalPolicy.SNAPSHOT (remove the cluster and instances, but retain a snapshot of the data)
+        :param scaling: (deprecated) Scaling configuration of an Aurora Serverless database cluster. Default: - Serverless cluster is automatically paused after 5 minutes of being idle. minimum capacity: 2 ACU maximum capacity: 16 ACU
+        :param security_groups: (deprecated) Security group. Default: - a new security group is created.
+        :param storage_encryption_key: (deprecated) The KMS key for storage encryption. If you specify the SnapshotIdentifier property, the StorageEncrypted property value is inherited from the snapshot, and if the DB cluster is encrypted, the specified KmsKeyId property is used. Default: - the default master key will be used for storage encryption
+        :param subnet_group: (deprecated) Existing subnet group for the cluster. Default: - a new subnet group will be created.
+        :param vpc_subnets: (deprecated) Where to place the instances within the VPC. Default: - the VPC default strategy if not specified.
+
+        :stability: deprecated
         '''
         if isinstance(scaling, dict):
             scaling = aws_cdk.aws_rds.ServerlessScalingOptions(**scaling)
@@ -352,18 +389,23 @@ class ServerlessClusterFromSnapshotProps:
 
     @builtins.property
     def engine(self) -> aws_cdk.aws_rds.IClusterEngine:
-        '''What kind of database to start.'''
+        '''(deprecated) What kind of database to start.
+
+        :stability: deprecated
+        '''
         result = self._values.get("engine")
         assert result is not None, "Required property 'engine' is missing"
         return typing.cast(aws_cdk.aws_rds.IClusterEngine, result)
 
     @builtins.property
     def snapshot_identifier(self) -> builtins.str:
-        '''The identifier for the DB snapshot or DB cluster snapshot to restore from.
+        '''(deprecated) The identifier for the DB snapshot or DB cluster snapshot to restore from.
 
         You can use either the name or the Amazon Resource Name (ARN) to specify a DB cluster snapshot. However, you can use only the ARN to specify a DB snapshot.
 
         After you restore a DB cluster with a SnapshotIdentifier property, you must specify the same SnapshotIdentifier property for any future updates to the DB cluster. When you specify this property for an update, the DB cluster is not restored from the snapshot again, and the data in the database is not changed. However, if you don't specify the SnapshotIdentifier property, an empty DB cluster is created, and the original DB cluster is deleted. If you specify a property that is different from the previous snapshot restore property, a new DB cluster is restored from the specified SnapshotIdentifier property, and the original DB cluster is deleted.
+
+        :stability: deprecated
         '''
         result = self._values.get("snapshot_identifier")
         assert result is not None, "Required property 'snapshot_identifier' is missing"
@@ -371,97 +413,117 @@ class ServerlessClusterFromSnapshotProps:
 
     @builtins.property
     def vpc(self) -> aws_cdk.aws_ec2.IVpc:
-        '''The VPC that this Aurora Serverless cluster has been created in.'''
+        '''(deprecated) The VPC that this Aurora Serverless cluster has been created in.
+
+        :stability: deprecated
+        '''
         result = self._values.get("vpc")
         assert result is not None, "Required property 'vpc' is missing"
         return typing.cast(aws_cdk.aws_ec2.IVpc, result)
 
     @builtins.property
     def backup_retention(self) -> typing.Optional[aws_cdk.Duration]:
-        '''The number of days during which automatic DB snapshots are retained.
+        '''(deprecated) The number of days during which automatic DB snapshots are retained.
 
         Automatic backup retention cannot be disabled on serverless clusters.
         Must be a value from 1 day to 35 days.
 
         :default: Duration.days(1)
+
+        :stability: deprecated
         '''
         result = self._values.get("backup_retention")
         return typing.cast(typing.Optional[aws_cdk.Duration], result)
 
     @builtins.property
     def cluster_identifier(self) -> typing.Optional[builtins.str]:
-        '''An optional identifier for the cluster.
+        '''(deprecated) An optional identifier for the cluster.
 
         :default: - A name is automatically generated.
+
+        :stability: deprecated
         '''
         result = self._values.get("cluster_identifier")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def credentials(self) -> typing.Optional[aws_cdk.aws_rds.Credentials]:
-        '''Credentials for the administrative user.
+        '''(deprecated) Credentials for the administrative user.
 
         :default: - A username of 'admin' and SecretsManager-generated password
+
+        :stability: deprecated
         '''
         result = self._values.get("credentials")
         return typing.cast(typing.Optional[aws_cdk.aws_rds.Credentials], result)
 
     @builtins.property
     def default_database_name(self) -> typing.Optional[builtins.str]:
-        '''Name of a database which is automatically created inside the cluster.
+        '''(deprecated) Name of a database which is automatically created inside the cluster.
 
         :default: - Database is not created in cluster.
+
+        :stability: deprecated
         '''
         result = self._values.get("default_database_name")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def deletion_protection(self) -> typing.Optional[builtins.bool]:
-        '''Indicates whether the DB cluster should have deletion protection enabled.
+        '''(deprecated) Indicates whether the DB cluster should have deletion protection enabled.
 
         :default: - true if removalPolicy is RETAIN, false otherwise
+
+        :stability: deprecated
         '''
         result = self._values.get("deletion_protection")
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def enable_data_api(self) -> typing.Optional[builtins.bool]:
-        '''Whether to enable the Data API.
+        '''(deprecated) Whether to enable the Data API.
 
         :default: false
 
         :see: https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/data-api.html
+        :stability: deprecated
         '''
         result = self._values.get("enable_data_api")
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def parameter_group(self) -> typing.Optional[aws_cdk.aws_rds.IParameterGroup]:
-        '''Additional parameters to pass to the database engine.
+        '''(deprecated) Additional parameters to pass to the database engine.
 
         :default: - no parameter group.
+
+        :stability: deprecated
         '''
         result = self._values.get("parameter_group")
         return typing.cast(typing.Optional[aws_cdk.aws_rds.IParameterGroup], result)
 
     @builtins.property
     def removal_policy(self) -> typing.Optional[aws_cdk.RemovalPolicy]:
-        '''The removal policy to apply when the cluster and its instances are removed from the stack or replaced during an update.
+        '''(deprecated) The removal policy to apply when the cluster and its instances are removed from the stack or replaced during an update.
 
         :default: - RemovalPolicy.SNAPSHOT (remove the cluster and instances, but retain a snapshot of the data)
+
+        :stability: deprecated
         '''
         result = self._values.get("removal_policy")
         return typing.cast(typing.Optional[aws_cdk.RemovalPolicy], result)
 
     @builtins.property
     def scaling(self) -> typing.Optional[aws_cdk.aws_rds.ServerlessScalingOptions]:
-        '''Scaling configuration of an Aurora Serverless database cluster.
+        '''(deprecated) Scaling configuration of an Aurora Serverless database cluster.
 
         :default:
 
         - Serverless cluster is automatically paused after 5 minutes of being idle.
         minimum capacity: 2 ACU
         maximum capacity: 16 ACU
+
+        :stability: deprecated
         '''
         result = self._values.get("scaling")
         return typing.cast(typing.Optional[aws_cdk.aws_rds.ServerlessScalingOptions], result)
@@ -470,38 +532,46 @@ class ServerlessClusterFromSnapshotProps:
     def security_groups(
         self,
     ) -> typing.Optional[typing.List[aws_cdk.aws_ec2.ISecurityGroup]]:
-        '''Security group.
+        '''(deprecated) Security group.
 
         :default: - a new security group is created.
+
+        :stability: deprecated
         '''
         result = self._values.get("security_groups")
         return typing.cast(typing.Optional[typing.List[aws_cdk.aws_ec2.ISecurityGroup]], result)
 
     @builtins.property
     def storage_encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.IKey]:
-        '''The KMS key for storage encryption.
+        '''(deprecated) The KMS key for storage encryption.
 
         If you specify the SnapshotIdentifier property, the StorageEncrypted property value is inherited from the snapshot, and if the DB cluster is encrypted, the specified KmsKeyId property is used.
 
         :default: - the default master key will be used for storage encryption
+
+        :stability: deprecated
         '''
         result = self._values.get("storage_encryption_key")
         return typing.cast(typing.Optional[aws_cdk.aws_kms.IKey], result)
 
     @builtins.property
     def subnet_group(self) -> typing.Optional[aws_cdk.aws_rds.ISubnetGroup]:
-        '''Existing subnet group for the cluster.
+        '''(deprecated) Existing subnet group for the cluster.
 
         :default: - a new subnet group will be created.
+
+        :stability: deprecated
         '''
         result = self._values.get("subnet_group")
         return typing.cast(typing.Optional[aws_cdk.aws_rds.ISubnetGroup], result)
 
     @builtins.property
     def vpc_subnets(self) -> typing.Optional[aws_cdk.aws_ec2.SubnetSelection]:
-        '''Where to place the instances within the VPC.
+        '''(deprecated) Where to place the instances within the VPC.
 
         :default: - the VPC default strategy if not specified.
+
+        :stability: deprecated
         '''
         result = self._values.get("vpc_subnets")
         return typing.cast(typing.Optional[aws_cdk.aws_ec2.SubnetSelection], result)
